summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/audio/exidy.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/audio/exidy.cpp')
-rw-r--r--src/mame/audio/exidy.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/audio/exidy.cpp b/src/mame/audio/exidy.cpp
index 55dda4ea22b..8220c3e1af7 100644
--- a/src/mame/audio/exidy.cpp
+++ b/src/mame/audio/exidy.cpp
@@ -180,7 +180,7 @@ void exidy_sound_device::common_sh_start()
m_sh6840_clocks_per_sample = (int)(SH6840_CLOCK.dvalue() / (double)sample_rate * (double)(1 << 24));
/* allocate the stream */
- m_stream = machine().sound().stream_alloc(*this, 0, 1, sample_rate);
+ m_stream = stream_alloc_legacy(0, 1, sample_rate);
sh6840_register_state_globals();
}
@@ -239,10 +239,10 @@ void exidy_sound_device::device_reset()
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void exidy_sound_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void exidy_sound_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
sh6840_timer_channel *sh6840_timer = m_sh6840_timer;
@@ -239,10 +239,10 @@ void exidy_sound_device::device_reset()
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------